==> google-events-0.3.4.tar.gz: google-events-0.3.4/src/google/events/cloud/datastream_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.events.cloud.datastream import gapic_version as package_version

__version__ = package_version.__version__



from .types.data import AvroFileFormat
from .types.data import BigQueryDestinationConfig
from .types.data import BigQueryProfile
from .types.data import ConnectionProfile
from .types.data import ConnectionProfileEventData
from .types.data import DestinationConfig
from .types.data import Error
from .types.data import ForwardSshTunnelConnectivity
from .types.data import GcsDestinationConfig
from .types.data import GcsProfile
from .types.data import JsonFileFormat
from .types.data import MysqlColumn
from .types.data import MysqlDatabase
from .types.data import MysqlProfile
from .types.data import MysqlRdbms
from .types.data import MysqlSourceConfig
from .types.data import MysqlSslConfig
from .types.data import MysqlTable
from .types.data import OracleColumn
from .types.data import OracleProfile
from .types.data import OracleRdbms
from .types.data import OracleSchema
from .types.data import OracleSourceConfig
from .types.data import OracleTable
from .types.data import PostgresqlColumn
from .types.data import PostgresqlProfile
from .types.data import PostgresqlRdbms
from .types.data import PostgresqlSchema
from .types.data import PostgresqlSourceConfig
from .types.data import PostgresqlTable
from .types.data import PrivateConnection
from .types.data import PrivateConnectionEventData
from .types.data import PrivateConnectivity
from .types.data import Route
from .types.data import RouteEventData
from .types.data import SourceConfig
from .types.data import StaticServiceIpConnectivity
from .types.data import Stream
from .types.data import StreamEventData
from .types.data import VpcPeeringConfig

__all__ = (
'AvroFileFormat',
'BigQueryDestinationConfig',
'BigQueryProfile',
'ConnectionProfile',
'ConnectionProfileEventData',
'DestinationConfig',
'Error',
'ForwardSshTunnelConnectivity',
'GcsDestinationConfig',
'GcsProfile',
'JsonFileFormat',
'MysqlColumn',
'MysqlDatabase',
'MysqlProfile',
'MysqlRdbms',
'MysqlSourceConfig',
'MysqlSslConfig',
'MysqlTable',
'OracleColumn',
'OracleProfile',
'OracleRdbms',
'OracleSchema',
'OracleSourceConfig',
'OracleTable',
'PostgresqlColumn',
'PostgresqlProfile',
'PostgresqlRdbms',
'PostgresqlSchema',
'PostgresqlSourceConfig',
'PostgresqlTable',
'PrivateConnection',
'PrivateConnectionEventData',
'PrivateConnectivity',
'Route',
'RouteEventData',
'SourceConfig',
'StaticServiceIpConnectivity',
'Stream',
'StreamEventData',
'VpcPeeringConfig',
)

==> google-events-0.9.0.tar.gz: google-events-0.9.0/src/google/events/cloud/datastream_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.events.cloud.datastream_v1 import gapic_version as package_version

__version__ = package_version.__version__



from .types.data import AvroFileFormat
from .types.data import BigQueryDestinationConfig
from .types.data import BigQueryProfile
from .types.data import ConnectionProfile
from .types.data import ConnectionProfileEventData
from .types.data import DestinationConfig
from .types.data import Error
from .types.data import ForwardSshTunnelConnectivity
from .types.data import GcsDestinationConfig
from .types.data import GcsProfile
from .types.data import JsonFileFormat
from .types.data import MysqlColumn
from .types.data import MysqlDatabase
from .types.data import MysqlProfile
from .types.data import MysqlRdbms
from .types.data import MysqlSourceConfig
from .types.data import MysqlSslConfig
from .types.data import MysqlTable
from .types.data import OracleColumn
from .types.data import OracleProfile
from .types.data import OracleRdbms
from .types.data import OracleSchema
from .types.data import OracleSourceConfig
from .types.data import OracleTable
from .types.data import PostgresqlColumn
from .types.data import PostgresqlProfile
from .types.data import PostgresqlRdbms
from .types.data import PostgresqlSchema
from .types.data import PostgresqlSourceConfig
from .types.data import PostgresqlTable
from .types.data import PrivateConnection
from .types.data import PrivateConnectionEventData
from .types.data import PrivateConnectivity
from .types.data import Route
from .types.data import RouteEventData
from .types.data import SourceConfig
from .types.data import StaticServiceIpConnectivity
from .types.data import Stream
from .types.data import StreamEventData
from .types.data import VpcPeeringConfig

__all__ = (
'AvroFileFormat',
'BigQueryDestinationConfig',
'BigQueryProfile',
'ConnectionProfile',
'ConnectionProfileEventData',
'DestinationConfig',
'Error',
'ForwardSshTunnelConnectivity',
'GcsDestinationConfig',
'GcsProfile',
'JsonFileFormat',
'MysqlColumn',
'MysqlDatabase',
'MysqlProfile',
'MysqlRdbms',
'MysqlSourceConfig',
'MysqlSslConfig',
'MysqlTable',
'OracleColumn',
'OracleProfile',
'OracleRdbms',
'OracleSchema',
'OracleSourceConfig',
'OracleTable',
'PostgresqlColumn',
'PostgresqlProfile',
'PostgresqlRdbms',
'PostgresqlSchema',
'PostgresqlSourceConfig',
'PostgresqlTable',
'PrivateConnection',
'PrivateConnectionEventData',
'PrivateConnectivity',
'Route',
'RouteEventData',
'SourceConfig',
'StaticServiceIpConnectivity',
'Stream',
'StreamEventData',
'VpcPeeringConfig',
)
